@@ -26,14 +26,18 @@ Document = Union[dict, SON]
 
 
 class ExplainableCollection():
-    def __init__(self, collection):
+    def __init__(self, collection, verbosity=None, comment=None):
         self.collection = collection
         self.last_cmd_payload = None
+        self.verbosity = verbosity or "queryPlanner"
+        self.comment = comment
 
     def _explain_command(self, command):
         command_son = command.get_SON()
         explain_command = SON([("explain", command_son)])
-        explain_command["verbosity"] = "queryPlanner"
+        explain_command["verbosity"] = self.verbosity
+        if self.comment:
+            explain_command["comment"] = self.comment
         self.last_cmd_payload = command_son
         return self.collection.database.command(explain_command)
 
@@ -100,17 +104,26 @@ class ExplainableCollection():
               max_await_time_ms: int = None, batch_size: int = None,
               collation=None, start_at_operation_time=None, session=None,
               start_after=None):
-        change_stream_options = {"start_after":start_after,
-                                 "resume_after":resume_after,
-                                "start_at_operation_time":start_at_operation_time,
-                                 "full_document":full_document}
+
+        change_stream_options = {}
+        if start_after:
+            change_stream_options["startAfter"] = start_after
+        if resume_after:
+            change_stream_options["resumeAfter"] = resume_after
+        if start_at_operation_time:
+            change_stream_options["startAtOperationTime"] = start_at_operation_time
+        if full_document:
+            change_stream_options["fullDocument"] = full_document
+
         if pipeline is not None:
             pipeline = [{"$changeStream": change_stream_options}]+pipeline
         else:
             pipeline = [{"$changeStream": change_stream_options}]
-
+        cursor_args = {}
+        if batch_size:
+            cursor_args["batchSize"] = batch_size
         command = AggregateCommand(self.collection, pipeline,
-                                    {"batch_size":batch_size},
+                                   cursor_args,
                                    {"collation":collation, "max_await_time_ms":
                                        max_await_time_ms})
         return self._explain_command(command)
