@@ -12,7 +12,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-
 import unittest
 import subprocess
 import os
@@ -28,6 +27,7 @@ from pymongoexplain.explainable_collection import ExplainCollection, Document
 class CommandLogger(monitoring.CommandListener):
     def __init__(self):
         self.cmd_payload = {}
+
     def started(self, event):
         self.cmd_payload = event.command
 
@@ -37,6 +37,7 @@ class CommandLogger(monitoring.CommandListener):
     def failed(self, event):
         pass
 
+
 class TestExplainableCollection(unittest.TestCase):
     def setUp(self) -> None:
         self.logger = CommandLogger()
@@ -114,15 +115,14 @@ class TestExplainableCollection(unittest.TestCase):
         last_cmd_payload = self.explain.last_cmd_payload
         self._compare_command_dicts(last_cmd_payload, last_logger_payload)
 
-    @unittest.skip("Travis does not have replica sets set up yet")
     def test_watch(self):
         res = self.explain.watch()
         self.assertIn("queryPlanner", res["stages"][0]["$cursor"])
         self.collection.watch(pipeline=[{"$project": {"tags": 1}}],
-                               batch_size=10, full_document="updateLookup")
+                              batch_size=10, full_document="updateLookup")
         last_logger_payload = self.logger.cmd_payload
         res = self.explain.watch(pipeline=[{"$project": {"tags": 1}}],
-                            batch_size=10, full_document="updateLookup")
+                                 batch_size=10, full_document="updateLookup")
         self.assertIn("queryPlanner", res["stages"][0]["$cursor"])
         last_cmd_payload = self.explain.last_cmd_payload
         self._compare_command_dicts(last_cmd_payload, last_logger_payload)
@@ -218,6 +218,25 @@ class TestExplainableCollection(unittest.TestCase):
         from pymongoexplain import ExplainableCollection
         self.assertEqual(ExplainableCollection, ExplainCollection)
 
+    def test_verbosity(self):
+        res = self.explain.find({})
+        self.assertNotIn("executionStats", res)
+        self.assertNotIn("allPlansExecution", res.get("executionStats", []))
+        self.explain = ExplainCollection(self.collection, verbosity="executionStats")
+        res = self.explain.find({})
+        self.assertIn("executionStats", res)
+        self.assertNotIn("allPlansExecution", res["executionStats"])
+        self.explain = ExplainCollection(self.collection, verbosity="allPlansExecution")
+        res = self.explain.find({})
+        self.assertIn("executionStats", res)
+        self.assertIn("allPlansExecution", res["executionStats"])
+
+    def test_comment(self):
+        self.explain.find({})
+        self.assertNotIn("comment", self.logger.cmd_payload)
+        self.explain = ExplainCollection(self.collection, comment="comment")
+        self.explain.find({})
+        self.assertIn("comment", self.logger.cmd_payload)
 
 if __name__ == '__main__':
     unittest.main()
